@@ -4,6 +4,17 @@ from petsc4py import PETSc
 def main():
 
     n = 4
+
+    v = PETSc.Vec()
+    print(type(v))
+    v.createMPI(n, comm=PETSc.COMM_WORLD)
+    print(type(v))
+    # v.setSizes(n)
+    # v.assemble()
+    print(v.getLocalSize())
+    exit()
+
+
     da = PETSc.DMDA().create([n, n], stencil_width=1)
 
     rank = PETSc.COMM_WORLD.getRank()
@@ -11,6 +22,7 @@ def main():
     x = da.createGlobalVec()
     xa = da.getVecArray(x)
     (xs, xe), (ys, ye) = da.getRanges()
+    print(da.getRanges())
     for i in range(xs, xe):
         for j in range(ys, ye):
             xa[i, j] = j*n + i
